@@ -46,8 +46,7 @@ import glance_store
 from glance_store import capabilities
 from glance_store.common import utils
 from glance_store import exceptions
-from glance_store.i18n import _
-from glance_store.i18n import _LE
+from glance_store.i18n import _, _LE
 from glance_store import location
 
 
@@ -558,7 +557,7 @@ class Store(glance_store.Store):
         image_file = _Reader(image_file, verifier)
         headers = {}
         if image_size > 0:
-            headers.update({'Content-Length': image_size})
+            headers.update({'Content-Length': six.text_type(image_size)})
             data = image_file
         else:
             data = utils.chunkiter(image_file, CHUNKSIZE)
